# Linear interpolation (= approx) + linear extrapolation outside the range of available data

approxExtrap = function(x,y,xout){

   # Split xout into data to 
	# extrapolate (xout<min)
	# interpolate (xmin<xout<xmax)
	# extrapolate (xout>xmax)
   xmin = min(x)
   xmax = max(x)
   xout_in_x = (xout >= xmin) & (xout <= xmax)
   xout_inf_x = xout<xmin
   xout_sup_x = xout>xmax
   xo = order(x)
   nx = length(x)

   # Interpolation
   yout = xout+NA
   yout_tmp = approx(x,y,xout[xout_in_x])
   yout[xout_in_x] = yout_tmp$y

   # Extrapolation 1 : xout<xmin
   x1 = x[xo[1]]
   y1 = y[xo[1]]
   x2 = x[xo[2]]
   y2 = y[xo[2]]
   yout[xout_inf_x] = y1 + (xout[xout_inf_x]-x1)*(y2-y1)/(x2-x1)

   # Extrapolation 2 : xout>xmax
   x1 = x[xo[nx-1]]
   y1 = y[xo[nx-1]]
   x2 = x[xo[nx]]
   y2 = y[xo[nx]]
   yout[xout_sup_x] = y1 + (xout[xout_sup_x]-x1)*(y2-y1)/(x2-x1)

   return(yout)
}
